/* $Id: data.h,v 1.20 2003/04/17 23:36:57 marcusva Exp $ */

/*  This file is part of LingoTeach, the Language Teaching program 
 *  Copyright (C) 2001-2003 The LingoTeach Team
 *
 *  This program is free software; you can redistribute it and/or modify 
 *  it under the terms of the GNU General Public License as published by 
 *  the Free Software Foundation; either version 2 of the License, or 
 *  (at your option) any later version.  
 *
 *  This program is distributed in the hope that it will be useful, 
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of 
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the 
 *  GNU General Public License for more details.  
 *
 *  You should have received a copy of the GNU General Public License 
 *  along with this program; if not, write to the Free Software 
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA. 
 */

#ifndef __DATA_DATA_H__
#define __DATA_DATA_H__

#include "meaning.h"
#include "iterator.h"
#include "language.h"

/** 
 *  This file defines all functions that can be used to access
 *  data. No XML filenames should be ever visible outside this module.
 */

/**
 * returns a fresh, virginal meaningPtr 
 */
meaningPtr
data_meaning_get_new ();

/**
 * Returns a meaning that is the same type of thing as the one that
 * is passed to it. This helps to make sure that the multiple choice
 * answers are not obvious.  
 */
meaningPtr
data_meaning_get_similar (meaningPtr like_this);

/**
 * Returns a list of meanings which contain 
 *  the expression exp. 
 */
int
data_meaning_find_exp (char* exp, int id);

/**
 * returns a meaningPtr containing the meaning, which has
 * the given id
 */
meaningPtr
data_meaning_get_by_word_id (int id);

/**
 * will increase the number of displays and calls the 
 * internal _data_write_meaning () for writing all to the 
 * temporary file
 */
void 
data_meaning_increase_knowledge (meaningPtr meaning);

/**
 * adds a new meaning to the lesson file of the user
 */
gboolean 
data_meaning_add_new (meaningPtr new_meaning);

/**
 * prepares  a lesson file for addition to the
 * currently used list of lessons
 */
gboolean 
data_lesson_add_file (char* filename);

/**
 * removes a lesson file from the list of used ones
 */
gboolean
data_lesson_remove_file (char* filename);

/**
 * returns the lesson path from the lessonDataPtr with the correct number
 */
char*
data_lesson_return_path (int number);

/**
 * searches the internal list for the correct file and determines 
 * the last meaing id, replaces the old data_meaning_get_max_word_id
 */
int
data_lesson_get_max_meaning (char* filename);

/**
 * modifies the user_defined flag of a file in the internal list, 
 * so that it is applied to the 'list' of used ones 
 */
gboolean
data_lesson_use_file (char* filename, gboolean use);

/**
 * return TRUE, if the file given as arg is currently marked as used
 * in the internal list
 */
gboolean
data_lesson_return_used (char* filename);

/**
 * tests, whether user configurations already exist 
 * or not
 */
void
data_conf_test_user_config ();

/**
 * writes changes from the user configuration to the
 * files
 */
void
data_conf_write_user_config ();

/**	 
 * saves the selected lesson files to the configuration file	 
 */	 
void	 
data_conf_write_lesson_config ();	 

gchar**
data_lang_get_languages ();

char*
data_lang_get_language (enum languages lang);

void 
data_lang_set_language (enum languages lang, char* new_lang);

int
data_lang_get_max_languages ();

#endif /* __DATA_DATA_H__ */
