/* $Id: lesson.h,v 1.15 2003/03/27 20:20:56 marcusva Exp $ */

/*  This file is part of LingoTeach, the Language Teaching program 
 *  Copyright (C) 2001-2003 The LingoTeach Team
 *
 *  This program is free software; you can redistribute it and/or modify 
 *  it under the terms of the GNU General Public License as published by 
 *  the Free Software Foundation; either version 2 of the License, or 
 *  (at your option) any later version.  
 *
 *  This program is distributed in the hope that it will be useful, 
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of 
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the 
 *  GNU General Public License for more details.  
 *
 *  You should have received a copy of the GNU General Public License 
 *  along with this program; if not, write to the Free Software 
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA. 
 */

#ifndef __DATA_LESSON_H__
#define __DATA_LESSON_H__

#include <libxml/xpath.h>
/* for gboolean */
#include <glib/gtypes.h>

enum xml_data 
{
  LESSON = 0,
  LANGUAGE
};

/**
 * _lesson_data, lessonData, lessonDataPtr:
 * stores the available lesson files
 *
 * xmlDocPtr lesson_file is created by xmlParseFile,
 * number is automatically increased
 * meanings is automatically fetched from the file 
 * next points to the next struct containing the next lesson
 * prev points to the previous struct containing the next lesson
 *
 */
typedef struct _lesson_data lessonData;
typedef lessonData *lessonDataPtr;

struct _lesson_data
{
  xmlDocPtr lesson_file;     /* the xmlDocPtr for parsing, etc. */
  xmlXPathContextPtr x_path; /* the xmlXPathContextPtr for the lesson */ 
  int number;                /* internal number, starting by 0 */
  int meanings;              /* count of meanings in the file */
  gboolean user_defined;     /* user defined file */
  char* path;                /* path to the lesson file */
  struct _lesson_data *next; /* pointer to the next xmlDocPtr */
  struct _lesson_data *prev; /* pointer to the prev xmlDocPtr */
};

/**
 * figures out and returns (on success) the base data directory 
 */
char*
_data_lesson_get_base_dir ();

/**
 * adds a lesson file to the current list of used lesson files
 */
lessonDataPtr
_data_lesson_add_file (lessonDataPtr curr_lesson_data);

/**
 * deletes a lesson file from the current list  of used lesson files
 */
lessonDataPtr
_data_lesson_delete_file (lessonDataPtr curr_lesson_data);

/** 
 * renumberation of the linked list
 */
void
_data_lesson_renumber_list ();

/**
 * returns the current list of used lesson files for other,
 * outside defined functions (meaning.c, etc.)
 */
lessonDataPtr
_data_lesson_get_used_lessons ();

/**
 * returns a xmlXPathContextPtr of the given xmlDocPtr
 */
xmlXPathContextPtr
_data_lesson_get_xpath (xmlDocPtr doc);

/**
 * small helper function to determine the absolute path
 * of the given path
 */
void
_data_lesson_get_abs_path (char* path);

/** 
 * helper function for getting the user lesson
 */
xmlDocPtr
_data_lesson_get_user_lesson ();

#endif /* __DATA_LESSON_H__ */
